@@ -113,7 +113,6 @@ def test_tag_hashability():
 
 
 @pytest.mark.remote_data
-@pytest.mark.flaky(reruns=5)
 def test_entries_from_fido_search_result(fido_search_result):
     entries = list(entries_from_fido_search_result(fido_search_result))
     # 66 entries for 8 instruments in fido_search_result
@@ -247,12 +246,12 @@ def test_entry_from_qr_block_kev(qr_block_with_kev_unit):
     entry = DatabaseEntry._from_query_result_block(qr_block_with_kev_unit)
     assert entry.source == 'RHESSI'
     assert entry.provider == 'LSSP'
-    assert entry.fileid in ['/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
-                            '/hessidata/2011/09/20/hsi_20110920_010920_001.fits']
-    assert entry.observation_time_start in [datetime(2011, 9, 20, 1, 9, 20),
-                                            datetime(2011, 9, 19, 23, 33, 40)]
-    assert entry.observation_time_end in [datetime(2011, 9, 20, 2, 27, 40),
-                                          datetime(2011, 9, 20, 1, 9, 20)]
+    assert entry.fileid in ['/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
+                            '/hessidata/2011/09/19/hsi_20110919_233340_002.fits']
+    assert entry.observation_time_start in [
+        datetime(2011, 9, 20, 1, 9, 20), datetime(2011, 9, 19, 23, 33, 40)]
+    assert entry.observation_time_end in [
+        datetime(2011, 9, 20, 2, 27, 40), datetime(2011, 9, 20, 1, 9, 20)]
     assert entry.instrument == 'RHESSI'
     assert round(entry.wavemin, 3) == 0.413
     assert round(entry.wavemax, 7) == 0.0000729
@@ -412,7 +411,7 @@ def test_entries_from_dir_recursively_true():
         entries = list(entries_from_dir(testdir, True,
                                         default_waveunit='angstrom',
                                         time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 130
+    assert len(entries) == 131
 
 
 def test_entries_from_dir_recursively_false():
@@ -420,7 +419,7 @@ def test_entries_from_dir_recursively_false():
         entries = list(entries_from_dir(testdir, False,
                                         default_waveunit='angstrom',
                                         time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 109
+    assert len(entries) == 110
 
 
 @pytest.mark.remote_data
@@ -444,7 +443,6 @@ def test_entry_from_query_results_with_none_wave(qr_with_none_waves):
     list(entries_from_query_result(qr_with_none_waves))
 
 
-@pytest.mark.xfail
 @pytest.mark.remote_data
 def test_entry_from_query_results_with_none_wave_and_default_unit(
         qr_with_none_waves):
