@@ -244,9 +244,14 @@ def _create_or(walker, query, factory):
 
 class UnifiedDownloaderFactory(BasicRegistrationFactory):
     """
-    sunpy.net.Fido(\\*args, \\*\\*kwargs)
+    Fido is a unified data search and retrieval tool.
+
+    It provides simultaneous access to a variety of online data sources, some
+    cover multiple instruments and data products like the Virtual Solar
+    Observatory and some are specific to a single source.
+
+    For details of using `~sunpy.net.Fido` see :ref:`fido_guide`.
 
-    Search and Download data from a variety of supported sources.
     """
 
     def search(self, *query):
@@ -255,7 +260,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Examples
         --------
-        Query for LYRALightCurve data for the time range ('2012/3/4','2012/3/6')
+        Query for LYRA timeseries data for the time range ('2012/3/4','2012/3/6')
 
         >>> from sunpy.net import Fido, attrs as a
         >>> import astropy.units as u
